#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `auth_oauth` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-auth-oauth",
    version = "7.0.406",
    description = "OAuth2 Authentication",
    long_description = 
"""

Allow users to login through OAuth2 Provider.
=============================================
""",
    url = "http://www.openerp.com",
    author = "OpenERP s.a.",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.auth_oauth': ".",
    },
    packages = ["openerp.addons.auth_oauth","openerp.addons.auth_oauth.controllers"],
    package_data = {
        'openerp.addons.auth_oauth': ["i18n/*.po*","auth_oauth_view.xml","auth_oauth_data.yml","auth_oauth_data.xml","res_config.xml","res_users.xml","static/lib/zocial/sample.html","static/lib/zocial/css/zocial-regular-webfont.woff","static/lib/zocial/css/zocial-regular-webfont.ttf","static/lib/zocial/css/zocial-regular-webfont.eot","static/lib/zocial/css/zocial-regular-webfont.svg","static/src/xml/auth_oauth.xml","static/src/js/auth_oauth.js","i18n/hr.po","i18n/sl.po","i18n/ru.po","i18n/en_GB.po","i18n/cs.po","i18n/pt_BR.po","i18n/ro.po","i18n/es.po","i18n/it.po","i18n/nl.po","i18n/sv.po","i18n/tr.po","i18n/de.po","i18n/hu.po","i18n/mk.po","i18n/fr.po","i18n/zh_CN.po","i18n/pl.po","i18n/nb.po","i18n/ar.po","i18n/pt.po","security/ir.model.access.csv","auth_oauth_data.xml","auth_oauth_data.yml","auth_oauth_view.xml","security/ir.model.access.csv","static/src/xml/auth_oauth.xml","static/lib/zocial/css/zocial.css","static/src/css/auth_oauth.css","static/src/js/auth_oauth.js"],
    },
    install_requires = ["openerp-core","openerp-web","openerp-base-setup"],
    tests_require = ["unittest2"],
)
